from nbtex.core.Ast import makeVar
class ArrowsSymbols:
    def __init__(self):
        pass

    @property
    def Leftarrow(self):
        return makeVar(r"\Leftarrow")

    @property
    def leftharpoonup(self):
        return makeVar(r"\leftharpoonup")

    @property
    def leftharpoondown(self):
        return makeVar(r"\leftharpoondown")

    @property
    def leftleftarrows(self):
        return makeVar(r"\leftleftarrows")

    @property
    def rightarrow(self):
        return makeVar(r"\rightarrow")

    @property
    def Rightarrow(self):
        return makeVar(r"\Rightarrow")

    @property
    def rightharpoonup(self):
        return makeVar(r"\rightharpoonup")

    @property
    def rightharpoondown(self):
        return makeVar(r"\rightharpoondown")

    @property
    def rightrightarrows(self):
        return makeVar(r"\rightrightarrows")

    @property
    def uparrow(self):
        return makeVar(r"\uparrow")

    @property
    def Uparrow(self):
        return makeVar(r"\Uparrow")

    @property
    def upharpoonleft(self):
        return makeVar(r"\upharpoonleft")

    @property
    def upharpoonright(self):
        return makeVar(r"\upharpoonright")

    @property
    def upuparrows(self):
        return makeVar(r"\upuparrows")

    @property
    def downarrow(self):
        return makeVar(r"\downarrow")

    @property
    def Downarrow(self):
        return makeVar(r"\Downarrow")

    @property
    def downharpoonleft(self):
        return makeVar(r"\downharpoonleft")

    @property
    def downharpoonright(self):
        return makeVar(r"\downharpoonright")

    @property
    def downdownarrows(self):
        return makeVar(r"\downdownarrows")

    @property
    def longleftarrow(self):
        return makeVar(r"\longleftarrow")

    @property
    def Longleftarrow(self):
        return makeVar(r"\Longleftarrow")

    @property
    def hookleftarrow(self):
        return makeVar(r"\hookleftarrow")

    @property
    def leftrightharpoons(self):
        return makeVar(r"\leftrightharpoons")

    @property
    def leftrightarrows(self):
        return makeVar(r"\leftrightarrows")

    @property
    def Lleftarrow(self):
        return makeVar(r"\Lleftarrow")

    @property
    def Lsh(self):
        return makeVar(r"\Lsh")

    @property
    def leftarrowtail(self):
        return makeVar(r"\leftarrowtail")

    @property
    def twoheadleftarrow(self):
        return makeVar(r"\twoheadleftarrow")

    @property
    def curvearrowleft(self):
        return makeVar(r"\curvearrowleft")

    @property
    def circlearrowleft(self):
        return makeVar(r"\circlearrowleft")

    @property
    def looparrowleft(self):
        return makeVar(r"\looparrowleft")

    @property
    def longrightarrow(self):
        return makeVar(r"\longrightarrow")

    @property
    def Longrightarrow(self):
        return makeVar(r"\Longrightarrow")

    @property
    def hookrightarrow(self):
        return makeVar(r"\hookrightarrow")

    @property
    def rightleftharpoons(self):
        return makeVar(r"\rightleftharpoons")

    @property
    def rightleftarrows(self):
        return makeVar(r"\rightleftarrows")

    @property
    def Rrightarrow(self):
        return makeVar(r"\Rrightarrow")

    @property
    def Rsh(self):
        return makeVar(r"\Rsh")

    @property
    def rightarrowtail(self):
        return makeVar(r"\rightarrowtail")

    @property
    def twoheadrightarrow(self):
        return makeVar(r"\twoheadrightarrow")

    @property
    def curvearrowright(self):
        return makeVar(r"\curvearrowright")

    @property
    def circlearrowright(self):
        return makeVar(r"\circlearrowright")

    @property
    def looparrowright(self):
        return makeVar(r"\looparrowright")

    @property
    def leftrightarrow(self):
        return makeVar(r"\leftrightarrow")

    @property
    def longleftrightarrow(self):
        return makeVar(r"\longleftrightarrow")

    @property
    def updownarrow(self):
        return makeVar(r"\updownarrow")

    @property
    def nleftarrow(self):
        return makeVar(r"\nleftarrow")

    @property
    def nrightarrow(self):
        return makeVar(r"\nrightarrow")

    @property
    def nleftrightarrow(self):
        return makeVar(r"\nleftrightarrow")

    @property
    def Leftrightarrow(self):
        return makeVar(r"\Leftrightarrow")

    @property
    def Longleftrightarrow(self):
        return makeVar(r"\Longleftrightarrow")

    @property
    def Updownarrow(self):
        return makeVar(r"\Updownarrow")

    @property
    def nLeftarrow(self):
        return makeVar(r"\nLeftarrow")

    @property
    def nRightarrow(self):
        return makeVar(r"\nRightarrow")

    @property
    def nLeftrightarrow(self):
        return makeVar(r"\nLeftrightarrow")

    @property
    def mapsto(self):
        return makeVar(r"\mapsto")

    @property
    def longmapsto(self):
        return makeVar(r"\longmapsto")

    @property
    def multimap(self):
        return makeVar(r"\multimap")

    @property
    def rightsquigarrow(self):
        return makeVar(r"\rightsquigarrow")

    @property
    def leftrightsquigarrow(self):
        return makeVar(r"\leftrightsquigarrow")

    @property
    def swarrow(self):
        return makeVar(r"\swarrow")

    @property
    def searrow(self):
        return makeVar(r"\searrow")

    @property
    def nwarrow(self):
        return makeVar(r"\nwarrow")

    @property
    def nearrow(self):
        return makeVar(r"\nearrow")


Arrow = ArrowsSymbols()